package journey;

import vehicle.Vehicle;

public class Journey {
	public static int nbMaxVehicles = 100;
	private City city1;
	private City city2;

	private int distance;
	private int passengerTicket;

	private Vehicle[] vehicles;
	private int iNextVehicle = 0;

	public Journey(City city1, City city2, int distance, int passengerTicket) {
		this.city1 = city1;
		this.city2 = city2;
		this.distance = distance;
		this.passengerTicket = passengerTicket;
		this.vehicles = new Vehicle[nbMaxVehicles];
	}

	// ajouter un véhicule au trajet - pas d'ajout si une des deux villes ne peut
	// pas accueillir le véhicule
	public boolean addVehicle(Vehicle v) {
		if (v.compatibleWith(city1) && v.compatibleWith(city2)) {
			vehicles[iNextVehicle] = v;
			iNextVehicle++;
			return true;
		}
		return false;
	}

	// nombre de passagers transportés sur une journée
	public int passengersPerDay() {
		int nbPassengers = 0;
		for (int i = 0; i < iNextVehicle; i++) {
			Vehicle v = vehicles[i];
			nbPassengers += v.getPassengers() * v.nbJourneyPerDay(distance);
		}

		return nbPassengers;
	}

	public boolean contains(Vehicle v) {
		for (int i = 0; i < iNextVehicle; i++) {
			if (v.equals(vehicles[i]))
				return true;
		}
		return false;
	}

	public int incomePerDay() {
		return passengersPerDay() * passengerTicket;
	}

	public int costPerDay() {
		int cost = 0;
		for (int i = 0; i < iNextVehicle; i++) {
			Vehicle v = vehicles[i];
			cost += v.nbJourneyPerDay(distance) * distance * v.getKmCost();
		}

		return cost;
	}

	public int benefitPerDay() {
		return incomePerDay() - costPerDay();
	}

	public String toString() {
		return city1 + "-" + city2;
	}
}
